@@ -174,7 +174,7 @@ class Cache:
                         return data
 
                 else:  # cached data does not yet exist for this request, try to download and create cache
-                    logging.info("No cached data found. Downloading...")
+                    logging.info(f"No cached data found for {str(func.__name__)}. Loading data...")
                     data = func(api_path, response=response, livedata=livedata)
                     if data is not None:
                         new_cached = {'version': cls._API_CORE_VERSION, 'data': data}
@@ -187,7 +187,7 @@ class Cache:
 
             else:  # cache was not enabled
                 if not cls._has_been_warned:  # warn only once
-                    logging.warning("\n\nNO CACHE! Api request caching has not been enabled! \n\t"
+                    logging.warning("\n\nNO CACHE! Api caching has not been enabled! \n\t"
                                     "It is highly recommended to enable this feature for much faster data loading!\n\t"
                                     "Use `fastf1.Cache.enable_cache('path/to/cache/')`\n")
 
@@ -968,6 +968,7 @@ def track_status_data(path, response=None, livedata=None):
     """
     if livedata is not None and livedata.has('TrackStatus'):
         # does not need any further processing
+        logging.info("Loading track status data")
         return livedata.get('TrackStatus')
     elif response is None:
         logging.info("Fetching track status data...")
@@ -1015,6 +1016,7 @@ def session_status_data(path, response=None, livedata=None):
     """
     if livedata is not None and livedata.has('SessionStatus'):
         # does not need any further processing
+        logging.info("Loading session status data")
         return livedata.get('SessionStatus')
     elif response is None:
         logging.info("Fetching session status data...")
