@@ -5,6 +5,7 @@ import asyncio
 import concurrent.futures
 import time
 import json
+import fastf1
 
 
 def messages_from_raw(r):
@@ -169,6 +170,8 @@ class SignalRClient:
             await asyncio.sleep(1)
 
     async def _async_start(self):
+        self.logger.info(f"Starting FastF1 live timing client "
+                         f"[v{fastf1.__version__}]")
         await asyncio.gather(asyncio.ensure_future(self._supervise()),
                              asyncio.ensure_future(self._run()))
         self._output_file.close()
